#-----------------------------------------------------
# fig2.R - to plot the variation of alpha with sample
# Rob MacKenzie
# May 2018
#-----------------------------------------------------

# reset all
rm(list=ls())
frame() # completes current plot
options("scipen"=10, "digits" = 4)

#load the lattice graphics package for extra functionality (e.g. xyplot)
library(lattice, biglm)

#read in data
fig2.data<-read.csv("fig2.csv")

#plot as stacked plots using par or layout functions
par(mfrow=c(2,1), mai=c(0.8, 1,0.2,0.5)) #control ugly white space between plots using mai
#plot the NOx data
plot(nox.sub.alpha ~ pop.low, data = fig2.data,
          log = "x", 
    # xaxt = "n", # suppresses default x-axis
     xlab = "",
     ylim = c(0.6, 1.2),
     ylab = list(expression(alpha), cex = 2.0))
abline(h=1)
#Add error bars
arrows(fig2.data$pop.low, fig2.data$nox.sub.alpha-fig2.data$nox.sub.alpha.sd, 
       fig2.data$pop.low, fig2.data$nox.sub.alpha+fig2.data$nox.sub.alpha.sd,
       code = 3, angle = 90, length = 0.05)
#plot the roads data
points(rd.sub.alpha ~ pop.low, data = fig2.data,
     pch = 19,
     # xaxt = "n", # suppresses default x-axis
     xlab = "",
     ylim = c(0.6, 1.2),
     ylab = list(expression(alpha), cex = 2.0))
#Add error bars
arrows(fig2.data$pop.low, fig2.data$rd.sub.alpha-fig2.data$rd.sub.alpha.sd, 
       fig2.data$pop.low, fig2.data$rd.sub.alpha+fig2.data$rd.sub.alpha.sd,
       code = 3, angle = 90, length = 0.05)
#Add a legend
legend(x = c(5e4, 5e4),y = c(0.8, 0.75), c(expression('NO'['x']),"road length"), 
       pch = c(1,19), bty = "n")

#Plot the r-square values
plot(nox.sub.rsq ~ pop.low, data = fig2.data, 
     log = "x", 
     xlab = list("Minimum urban population in sample of settlements", cex = 1.0),
     ylim = c(0.6, 1.0),
     ylab = list(expression(r^2), cex = 1.5))

#And again for road lengths
points(rd.sub.rsq ~ pop.low, data = fig2.data, 
     pch = 19,
     xlab = list("Minimum urban population in sample of settlements", cex = 1.0),
     ylim = c(0.6, 1.0),
     ylab = list(expression(r^2), cex = 1.5))
#And add the sample numbers
text(fig2.data$pop.low, fig2.data$nox.sub.rsq-0.05, paste(fig2.data$nox.sam.pul), cex = 0.8)
#Add a legend
legend(x = c(5e4, 5e4),y = c(0.75, 0.7), c(expression('NO'['x']),"road length"), 
       pch = c(1,19), bty = "n")


#And finally, plot the ratio of NOx and road length scalings
frame() # completes current plot
#ratios<-fig2.data$nox.sub.alpha/fig2.data$rd.sub.alpha #check what the numbers are
plot(nox.sub.alpha/rd.sub.alpha ~ pop.low, data = fig2.data,
     ylim = c(1.0, 1.4),
     ylab = list("Ratio of scaling factors", cex = 1.0),
     log = "x", 
     xlab = list("Minimum urban population in sample of settlements", cex = 1.0))
#abline(h=1)
