#-----------------------------------------------------
# hist2D - to plot the urban allometric datasets
# Rob MacKenzie
# May 2018
#-----------------------------------------------------

# reset all
rm(list=ls())
frame() # completes current plot

#load the lattice graphics package for extra functionality (e.g. xyplot)
library(lattice, ggplot2, grid)
setwd("U:/data/research/R_work")

# input work data
#city_test<-read.csv("city_test.csv") #short subsection of data for testing
city<-read.csv("UrbanData_revised.csv",na.strings = "#N/A") #na.strings strips out the 'no data' chars

#subset the data into working data frame ...
city_sub<-subset(city, Total.residents>1e2) #...using absolute population thresholds


# check columns input correctly
names(city_sub)
head(city_sub)
str(city_sub)

#current parameter being analysed (eg, 3 = area; 8 = rd length; 10 = NOx; 13 = CO2)
param.col = 10 
city_test<-subset(city_sub, city_sub[,param.col]>0) #...excluding zeros and no data -999s
#str reports the structure of the dataset - useful for spotting numerical arrays that contain chars etc
#variables for plotting must be "int" or "num"
#NB: subsetting does not change the variable type - eg if read-in as a factor will stay a factor
str(city_test)

#plotting: use plot.formula, tilde to define the stat model 
plot(city_test[,param.col] ~ Total.residents, data = city_test,
     #set log axes 
     log = "xy",
     xlab = list("Population", cex = 1.5),
     #The y-axis label is the xth (where x is param.col) element of the names in city_test
     ylab = list(names(city_test)[param.col], cex = 1.5))

#log transforms
log.param=log10(city_test[,param.col]) #transform parameter
log.pop=log10(city_test$Total.residents) #transform x-axis independent variable
#linear model
lin.sum<-summary(lm(log.param ~ log.pop)) #summary of the linear model
alpha<-round(lin.sum$coefficients[2,1:2], digits = 3) #slope and error on slope, rounded to 3 sig figs

#add line of best fit and slope
abline(coef = coef(lin.sum))
#legend("topleft", legend=round(alpha,digits = 3))
#alternative way of writing out the slope, as text on the graph at position given by first two elements
text(mean(city_test$Total.residents),ceiling(max(city_test[,param.col])),
     paste("alpha=",alpha[1],"+/-",alpha[2]))
#write out the r-square and correl coeff (root(r^2))
text(mean(city_test$Total.residents),ceiling(0.5*max(city_test[,param.col])),
     paste("r-squared=",round(lin.sum$adj.r.squared, digits = 2),"; n = ",dim(city_test)[1]))

#smoothScatter (note capital!) gives a 2D histogram
#plot histogram or'PDF' (NB: x before y when specifiying axes rather than model)
#smoothScatter(log.pop,log.param, nbin=50, 
#              #define a colour ramp
#              colramp = colorRampPalette(c("white",blues9)), 
#              #colramp = colorRampPalette(c("white",heat.colors(6))), #over-emphasises the outliers
#              nrpoints = 300, cex = 4, 
#              transformation = function(x) x^0.25, #not entirely sure what this does
#              xlab = list(expression('Log'['10']*'Population'), cex = 1.5),
#              #The y-axis label is the xth (where x is param.col) element of the names in city_test
#              #ylab = list(names(city_test)[param.col], cex = 1.5)
#              #prettify the axes labels if need be
#              ylab = list(expression('Log'['10']*'NO'['x']), cex = 1.5)
#              )

#2D histogram using ggplot2 because smoothScatter doesn't do legends easily...
scatframe<-data.frame(log.pop,log.param)
graf<-ggplot(data = scatframe, aes(x = log.pop, y = log.param)) +
  geom_bin2d() +
  labs(y = expression('Log'['10']*'NO'['x']),
       x = expression('Log'['10']*'Population'))
#add line of best fit and slope using geom
graf2<-graf + geom_smooth(method = "lm", col = "firebrick")

reg_vals<-paste("Slope =",alpha[1],"+/-",alpha[2])
my_grob<-grid.text(reg_vals, x = 0.75, y = 0.5)
graf3<-graf2+annotation_custom(my_grob)
plot(graf3)