#-----------------------------------------------------
# hist2D - to plot the urban allometric datasets
# Rob MacKenzie
# May 2018
#-----------------------------------------------------

# reset all
rm(list=ls())
frame() # completes current plot
options("scipen"=10, "digits" = 2)

#load the lattice graphics package for extra functionality (e.g. xyplot)
library(lattice, ggplot2, grid, gridExtra)
setwd("U:/data/research/R_work")

# input work data
#city_test<-read.csv("city_test.csv") #short subsection of data for testing
city<-read.csv("UrbanData_revised.csv",na.strings = "#N/A") #na.strings strips out the 'no data' chars

#subset the data into working data frame ...
city_sub<-subset(city, Total.residents>1e2) #...using absolute population thresholds


# check columns input correctly
names(city_sub)
head(city_sub)
str(city_sub)


#PANEL 1
#current parameter being analysed (eg, 3 = area; 8 = rd length; 10 = NOx; 13 = CO2)
param.col = 10 
city_test<-subset(city_sub, city_sub[,param.col]>0) #...excluding zeros and no data -999s

#log transforms
log.param=log10(city_test[,param.col]) #transform parameter
log.pop=log10(city_test$Total.residents) #transform x-axis independent variable
#linear model
lin.sum<-summary(lm(log.param ~ log.pop)) #summary of the linear model
alpha<-round(lin.sum$coefficients[2,1:2], digits = 3) #slope and error on slope, rounded to 3 sig figs

#2D histogram using ggplot2 because smoothScatter doesn't do legends easily...
scatframe<-data.frame(log.pop,log.param)
graf<-ggplot(data = scatframe, aes(x = log.pop, y = log.param)) +
  geom_bin2d() +
  scale_fill_continuous(limits = c(0, 100)) +
  labs(y = expression('Log'['10']*'NO'['x']),
       x = expression('Log'['10']*'Population'))
#add line of best fit and slope using geom
graf2<-graf + geom_smooth(method = "lm", col = "firebrick")

reg_vals<-paste("(a) Slope =",alpha[1],"+/-",alpha[2])
graf_1<-graf2 +
  annotate(geom = "text", x = 4, y = 4.5, 
           size = 3.5, label = reg_vals)
#plot(graf_1)


#PANEL 2
#current parameter being analysed (eg, 3 = area; 8 = rd length; 10 = NOx; 13 = CO2)
param.col = 13 
city_test<-subset(city_sub, city_sub[,param.col]>0) #...excluding zeros and no data -999s

#log transforms
log.param=log10(city_test[,param.col]) #transform parameter
log.pop=log10(city_test$Total.residents) #transform x-axis independent variable
#linear model
lin.sum<-summary(lm(log.param ~ log.pop)) #summary of the linear model
alpha<-round(lin.sum$coefficients[2,1:2], digits = 3) #slope and error on slope, rounded to 3 sig figs

#2D histogram using ggplot2 because smoothScatter doesn't do legends easily...
scatframe<-data.frame(log.pop,log.param)
graf<-ggplot(data = scatframe, aes(x = log.pop, y = log.param)) +
  geom_bin2d() +
  scale_fill_continuous(limits = c(0, 100)) +
  labs(y = expression('Log'['10']*'CO'['2']),
       x = expression('Log'['10']*'Population'))
#add line of best fit and slope using geom
graf2<-graf + geom_smooth(method = "lm", col = "firebrick")

reg_vals<-paste("(b) Slope =",alpha[1],"+/-",alpha[2])
graf_2<-graf2 +
  annotate(geom = "text", x = 4, y = 6.5, 
           size = 3.5, label = reg_vals)
#plot(graf_2)

#PANEL 3
#current parameter being analysed (eg, 3 = area; 8 = rd length; 10 = NOx; 13 = CO2)
param.col = 15 
city_test<-subset(city_sub, city_sub[,param.col]>0) #...excluding zeros and no data -999s

#log transforms
log.param=log10(city_test[,param.col]) #transform parameter
log.pop=log10(city_test$Total.residents) #transform x-axis independent variable
#linear model
lin.sum<-summary(lm(log.param ~ log.pop)) #summary of the linear model
alpha<-round(lin.sum$coefficients[2,1:2], digits = 3) #slope and error on slope, rounded to 3 sig figs

#2D histogram using ggplot2 because smoothScatter doesn't do legends easily...
scatframe<-data.frame(log.pop,log.param)
graf<-ggplot(data = scatframe, aes(x = log.pop, y = log.param)) +
  geom_bin2d() +
  scale_fill_continuous(limits = c(0, 100)) +
  labs(y = expression('Log'['10']*'PM'['10']),
       x = expression('Log'['10']*'Population'))
#add line of best fit and slope using geom
graf2<-graf + geom_smooth(method = "lm", col = "firebrick")

reg_vals<-paste("(c) Slope =",alpha[1],"+/-",alpha[2])
graf_3<-graf2 +
  annotate(geom = "text", x = 4.1, y = 3.5, 
           size = 3.5, label = reg_vals)
#plot(graf_3)


#PANEL 4
#current parameter being analysed (eg, 3 = area; 8 = rd length; 10 = NOx; 13 = CO2)
param.col = 12 
city_test<-subset(city_sub, city_sub[,param.col]>0) #...excluding zeros and no data -999s

#log transforms
log.param=log10(city_test[,param.col]) #transform parameter
log.pop=log10(city_test$Total.residents) #transform x-axis independent variable
#linear model
lin.sum<-summary(lm(log.param ~ log.pop)) #summary of the linear model
alpha<-round(lin.sum$coefficients[2,1:2], digits = 3) #slope and error on slope, rounded to 3 sig figs

#2D histogram using ggplot2 because smoothScatter doesn't do legends easily...
scatframe<-data.frame(log.pop,log.param)
graf<-ggplot(data = scatframe, aes(x = log.pop, y = log.param)) +
  geom_bin2d() +
  scale_fill_continuous(limits = c(0, 100)) +
  labs(y = expression('Log'['10']*'PM'['2.5']),
       x = expression('Log'['10']*'Population'))
#add line of best fit and slope using geom
graf2<-graf + geom_smooth(method = "lm", col = "firebrick")

reg_vals<-paste("(d) Slope =",alpha[1],"+/-",alpha[2])
graf_4<-graf2 +
  annotate(geom = "text", x = 4.1, y = 3.3, 
           size = 3.5, label = reg_vals)
#plot(graf_4)

#Plotting as a grid requires gridExtra library to be installed
grid.arrange(graf_1, graf_2, graf_3, graf_4)
